cwlVersion: v1.2
class: Workflow
doc: >-
  The workflow starts with selecting Inflammation as the search term. The
  workflow starts with selecting Penicillin as the search term. The workflow
  starts with selecting Cortisol as the search term. Gene sets with set labels
  containing Inflammation were queried from Enrichr[1]. Identified matching
  terms from the GWAS Catalog 2019[2] library were assembled into a collection
  of gene sets. A GMT was extracted from the Enrichr results for
  GWAS_Catalog_2019. All the identified gene sets were combined using the union
  set operation. Identified matching terms from the MGI Mammalian Phenotype
  Level 4 2019[4] library were assembled into a collection of gene sets. A GMT
  was extracted from the Enrichr results for
  MGI_Mammalian_Phenotype_Level_4_2019. All the identified gene sets were
  combined using the union set operation. Identified matching terms from the
  Human Phenotype Ontology[5] library were assembled into a collection of gene
  sets. A GMT was extracted from the Enrichr results for
  Human_Phenotype_Ontology. All the identified gene sets were combined using the
  union set operation. Gene sets with set labels containing Penicillin were
  queried from Enrichr[1]. Identified matching terms from the LINCS L1000 Chem
  Pert Consensus Sigs[6] library were assembled into a collection of gene sets.
  A GMT was extracted from the Enrichr results for
  LINCS_L1000_Chem_Pert_Consensus_Sigs. Gene sets with set labels containing
  Cortisol were queried from Enrichr[1]. Identified matching terms from the
  LINCS L1000 Chem Pert Consensus Sigs[6] library were assembled into a
  collection of gene sets. A GMT was extracted from the Enrichr results for
  LINCS_L1000_Chem_Pert_Consensus_Sigs. The gene sets collected were combined
  into one gene set library. Multiple GMTs were combined into one GMT. The
  collection of gene sets was then visualized with a Supervenn diagram Fig.. 

  1. Xie, Z. et al. Gene Set Knowledge Discovery with Enrichr. Current Protocols
  vol. 1 (2021). doi:10.1002/cpz1.90

  2. Sollis, E. et al. The NHGRI-EBI GWAS Catalog: knowledgebase and deposition
  resource. Nucleic Acids Research vol. 51 D977–D985 (2022).
  doi:10.1093/nar/gkac1010

  4. Blake, J. A. et al. Mouse Genome Database (MGD): Knowledgebase for
  mouse–human comparative biology. Nucleic Acids Research vol. 49 D981–D987
  (2020). doi:10.1093/nar/gkaa1083

  5. Köhler, S. et al. The Human Phenotype Ontology in 2021. Nucleic Acids
  Research vol. 49 D1207–D1217 (2020). doi:10.1093/nar/gkaa1043

  6. Evangelista, J. E. et al. SigCom LINCS: data and metadata search engine for
  a million gene expression signatures. Nucleic Acids Research vol. 50 W697–W709
  (2022). doi:10.1093/nar/gkac328
requirements: {}
inputs:
  step-1-data:
    label: Phenotype Input
    doc: Start with a Phenotype
    type: File
  step-2-data:
    label: Drug Input
    doc: Start with a Drug
    type: File
  step-3-data:
    label: Drug Input
    doc: Start with a Drug
    type: File
  step-20-data:
    label: Assemble GMT from Gene Sets
    doc: Group multiple independently generated gene sets into a single GMT
    type: File
outputs:
  step-1-output:
    label: Phenotype
    doc: Phenotype Term
    type: File
    outputSource: step-1/output
  step-2-output:
    label: Drug
    doc: Drug Term
    type: File
    outputSource: step-2/output
  step-3-output:
    label: Drug
    doc: Drug Term
    type: File
    outputSource: step-3/output
  step-4-output:
    label: Enrichr Term Search Results
    doc: Results of an Enrichr Term Search
    type: File
    outputSource: step-4/output
  step-5-output:
    label: Enrichr Phenotype Set
    doc: Set of Phenotypes
    type: File
    outputSource: step-5/output
  step-6-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-6/output
  step-7-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-7/output
  step-8-output:
    label: Enrichr Phenotype Set
    doc: Set of Phenotypes
    type: File
    outputSource: step-8/output
  step-9-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-9/output
  step-10-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-10/output
  step-11-output:
    label: Enrichr Phenotype Set
    doc: Set of Phenotypes
    type: File
    outputSource: step-11/output
  step-12-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-12/output
  step-13-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-13/output
  step-14-output:
    label: Enrichr Term Search Results
    doc: Results of an Enrichr Term Search
    type: File
    outputSource: step-14/output
  step-15-output:
    label: Enrichr Drug Set
    doc: Set of Drugs
    type: File
    outputSource: step-15/output
  step-16-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-16/output
  step-17-output:
    label: Enrichr Term Search Results
    doc: Results of an Enrichr Term Search
    type: File
    outputSource: step-17/output
  step-18-output:
    label: Enrichr Drug Set
    doc: Set of Drugs
    type: File
    outputSource: step-18/output
  step-19-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-19/output
  step-20-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-20/output
  step-21-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-21/output
  step-22-output:
    label: Supervenn Visualization
    doc: A visualization for comparing sets
    type: File
    outputSource: step-22/output
steps:
  step-1:
    run: Input[Phenotype].cwl
    label: Phenotype Input
    doc: Start with a Phenotype
    in:
      data:
        source: step-1-data
      outputFilename:
        default: step-1-output.json
    out:
      - output
  step-2:
    run: Input[Drug].cwl
    label: Drug Input
    doc: Start with a Drug
    in:
      data:
        source: step-2-data
      outputFilename:
        default: step-2-output.json
    out:
      - output
  step-3:
    run: Input[Drug].cwl
    label: Drug Input
    doc: Start with a Drug
    in:
      data:
        source: step-3-data
      outputFilename:
        default: step-3-output.json
    out:
      - output
  step-4:
    run: EnrichrTermSearch[Phenotype].cwl
    label: Extract Gene Sets Containing the Phenotype in the Set Label
    doc: Find Phenotype Terms in Enrichr Libraries
    in:
      inputs.term:
        label: Phenotype
        source: step-1/output
      outputFilename:
        default: step-4-output.json
    out:
      - output
  step-5:
    run: ExtractEnrichrTermSearch[GWAS_Catalog_2019].cwl
    label: Extract GWAS Phenotypes Associated with the Term Search
    doc: Extract Terms from the GWAS Catalog 2019 Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-4/output
      outputFilename:
        default: step-5-output.json
    out:
      - output
  step-6:
    run: EnrichrSetTToGMT[Phenotype].cwl
    label: Enrichr Phenotype Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Phenotype Set
        source: step-5/output
      outputFilename:
        default: step-6-output.json
    out:
      - output
  step-7:
    run: GMTUnion.cwl
    label: Compute Union Gene Set
    doc: Find the union set of all genes in the GMT
    in:
      inputs.gmt:
        label: Gene Matrix Transpose
        source: step-6/output
      outputFilename:
        default: step-7-output.json
    out:
      - output
  step-8:
    run: ExtractEnrichrTermSearch[MGI_Mammalian_Phenotype_Level_4_2019].cwl
    label: Extract MGI Mammalian Phenotypes Associated with the Term Search
    doc: Extract Terms from the MGI Mammalian Phenotype Level 4 2019 Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-4/output
      outputFilename:
        default: step-8-output.json
    out:
      - output
  step-9:
    run: EnrichrSetTToGMT[Phenotype].cwl
    label: Enrichr Phenotype Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Phenotype Set
        source: step-8/output
      outputFilename:
        default: step-9-output.json
    out:
      - output
  step-10:
    run: GMTUnion.cwl
    label: Compute Union Gene Set
    doc: Find the union set of all genes in the GMT
    in:
      inputs.gmt:
        label: Gene Matrix Transpose
        source: step-9/output
      outputFilename:
        default: step-10-output.json
    out:
      - output
  step-11:
    run: ExtractEnrichrTermSearch[Human_Phenotype_Ontology].cwl
    label: Extract Human Phenotypes Associated with the Term Search
    doc: Extract Terms from the Human Phenotype Ontology Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-4/output
      outputFilename:
        default: step-11-output.json
    out:
      - output
  step-12:
    run: EnrichrSetTToGMT[Phenotype].cwl
    label: Enrichr Phenotype Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Phenotype Set
        source: step-11/output
      outputFilename:
        default: step-12-output.json
    out:
      - output
  step-13:
    run: GMTUnion.cwl
    label: Compute Union Gene Set
    doc: Find the union set of all genes in the GMT
    in:
      inputs.gmt:
        label: Gene Matrix Transpose
        source: step-12/output
      outputFilename:
        default: step-13-output.json
    out:
      - output
  step-14:
    run: EnrichrTermSearch[Drug].cwl
    label: Extract Gene Sets Containing the Drug in the Set Label
    doc: Find Drug Terms in Enrichr Libraries
    in:
      inputs.term:
        label: Drug
        source: step-2/output
      outputFilename:
        default: step-14-output.json
    out:
      - output
  step-15:
    run: ExtractEnrichrTermSearch[LINCS_L1000_Chem_Pert_Consensus_Sigs].cwl
    label: Extract L1000 Chem Pert Signatures Containing the Term Search
    doc: Extract Terms from the LINCS L1000 Chem Pert Consensus Sigs Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-14/output
      outputFilename:
        default: step-15-output.json
    out:
      - output
  step-16:
    run: EnrichrSetTToGMT[Drug].cwl
    label: Enrichr Drug Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Drug Set
        source: step-15/output
      outputFilename:
        default: step-16-output.json
    out:
      - output
  step-17:
    run: EnrichrTermSearch[Drug].cwl
    label: Extract Gene Sets Containing the Drug in the Set Label
    doc: Find Drug Terms in Enrichr Libraries
    in:
      inputs.term:
        label: Drug
        source: step-3/output
      outputFilename:
        default: step-17-output.json
    out:
      - output
  step-18:
    run: ExtractEnrichrTermSearch[LINCS_L1000_Chem_Pert_Consensus_Sigs].cwl
    label: Extract L1000 Chem Pert Signatures Containing the Term Search
    doc: Extract Terms from the LINCS L1000 Chem Pert Consensus Sigs Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-17/output
      outputFilename:
        default: step-18-output.json
    out:
      - output
  step-19:
    run: EnrichrSetTToGMT[Drug].cwl
    label: Enrichr Drug Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Drug Set
        source: step-18/output
      outputFilename:
        default: step-19-output.json
    out:
      - output
  step-20:
    run: GenesetsToGMT.cwl
    label: Assemble GMT from Gene Sets
    doc: Group multiple independently generated gene sets into a single GMT
    in:
      data:
        source: step-20-data
      inputs.genesets:0:
        label: Gene Set
        source: step-7/output
      inputs.genesets:1:
        label: Gene Set
        source: step-10/output
      inputs.genesets:2:
        label: Gene Set
        source: step-13/output
      outputFilename:
        default: step-20-output.json
    out:
      - output
  step-21:
    run: GMTConcatenate.cwl
    label: Concatenate GMTs
    doc: Join several GMTs into one
    in:
      inputs.gmts:0:
        label: Gene Matrix Transpose
        source: step-16/output
      inputs.gmts:1:
        label: Gene Matrix Transpose
        source: step-19/output
      inputs.gmts:2:
        label: Gene Matrix Transpose
        source: step-20/output
      outputFilename:
        default: step-21-output.json
    out:
      - output
  step-22:
    run: SupervennFromGMT.cwl
    label: Compare sets with Supervenn
    doc: Interactively analyse overlap between sets
    in:
      inputs.gmt:
        label: Gene Matrix Transpose
        source: step-21/output
      outputFilename:
        default: step-22-output.json
    out:
      - output
